@@ -1,7 +1,4 @@
-# coding: utf-8
-u"""Общая кодовая база для проектов БЦ Образование."""
-from __future__ import absolute_import
-
+"""Общая кодовая база для проектов БЦ Образование."""
 
 #: Неопределенное значение.
 #:
