@@ -1,19 +1,19 @@
-# coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import os.path
 
-from django.db import migrations
+from django.db import (
+    migrations,
+)
 
-from educommon.django.db.migration.operations import CorrectSequence
-from educommon.django.db.migration.operations import LoadFixture
+from educommon.django.db.migration.operations import (
+    CorrectSequence,
+    LoadFixture,
+)
 
 
 APP_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
 
-class Migration(migrations.Migration):
 
+class Migration(migrations.Migration):
     dependencies = [
         ('async', '0001_initial'),
     ]
