@@ -1,22 +1,19 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-import six
-
-from .utils import get_audit_log_context
-from .utils import set_db_param
+from educommon.audit_log.utils import (
+    get_audit_log_context,
+    set_db_param,
+)
 
 
 try:
-    from django.utils.deprecation import MiddlewareMixin
+    from django.utils.deprecation import (
+        MiddlewareMixin,
+    )
 except ImportError:
     MiddlewareMixin = object
 
 
-
 class AuditLogMiddleware(MiddlewareMixin):
-
-    u"""Устанавливает параметры из запроса в текущей сессии БД.
+    """Устанавливает параметры из запроса в текущей сессии БД.
 
     Устанавливает в custom settings postgresql:
       - audit_log.user_id - id пользователя;
@@ -27,7 +24,7 @@ class AuditLogMiddleware(MiddlewareMixin):
     """
 
     def process_request(self, request):
-        for name, value in six.iteritems(get_audit_log_context(request)):
+        for name, value in get_audit_log_context(request).items():
             set_db_param('audit_log.' + name, value)
 
     def process_response(self, request, response):
