@@ -25,7 +25,10 @@ BEGIN
                     SET password '{password}'
                 );
             END IF;
-            PERFORM audit.update_triggers(FALSE);
+            IF {need_to_update_triggers} THEN
+                PERFORM audit.drop_all_triggers();
+                PERFORM audit.create_triggers();
+            END IF;
         END IF;
         PERFORM pg_advisory_unlock({lock_id});
     END IF;
