@@ -1,20 +1,18 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-from abc import ABCMeta
-from abc import abstractproperty
-
-import six
+from abc import (
+    ABCMeta,
+    abstractmethod,
+)
 
 
-class IConfig(six.with_metaclass(ABCMeta, object)):
-    u"""Конфигурация управлением доступом на основе ролей.
+class IConfig(metaclass=ABCMeta):
+    """Конфигурация управлением доступом на основе ролей.
 
     Позволяет ограничивать выбор классов, на которые может ссылаться
     :class:`~educommon.auth.rbac.models.UserRole` в атрибуте ``user``.
     """
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def user_types(self):
         """Типы классов пользователей, которым назначаются роли.
 
@@ -26,7 +24,7 @@ class IConfig(six.with_metaclass(ABCMeta, object)):
 
 
 class DefaultConfig(IConfig):
-    u"""Конфигурация без ограничения ролей пользователей."""
+    """Конфигурация без ограничения ролей пользователей."""
 
     user_types = False
 
