@@ -1,7 +1,3 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-
 # -----------------------------------------------------------------------------
 # Источники разрешений
 
@@ -11,8 +7,8 @@ PERM_SOURCE__DEPENDENCIES = 3
 
 
 PERM_SOURCES = {
-    PERM_SOURCE__ROLE: u'Редактируемая роль',
-    PERM_SOURCE__NESTED_ROLE: u'Вложенные роли',
-    PERM_SOURCE__DEPENDENCIES: u'Зависимые разрешения',
+    PERM_SOURCE__ROLE: 'Редактируемая роль',
+    PERM_SOURCE__NESTED_ROLE: 'Вложенные роли',
+    PERM_SOURCE__DEPENDENCIES: 'Зависимые разрешения',
 }
 # -----------------------------------------------------------------------------
