@@ -24,10 +24,6 @@ from django.utils.functional import (
 from m3.actions import (
     ControllerCache,
 )
-from m3_django_compat import (
-    atomic,
-    get_installed_apps,
-)
 
 from educommon.auth.rbac.models import (
     Permission,
@@ -35,6 +31,10 @@ from educommon.auth.rbac.models import (
 from educommon.utils.db.postgresql import (
     Lock,
 )
+from m3_django_compat import (
+    atomic,
+    get_installed_apps,
+)
 
 
 def _get_handler(handler):
@@ -104,7 +104,7 @@ def _set_permission(permission, name, title, description, hidden):
 class RBACManager:
     """Менеджер системы авторизации RBAC."""
 
-    post_init = Signal(providing_args=('changed',))
+    post_init = Signal()
     """Сигнал, отправляемый после обновления разрешений в БД.
 
     :param bool changed: Указывает, были ли в процессе инициализации подсистемы
