@@ -37,18 +37,10 @@ from m3.actions.results import (
     OperationResult,
     PreJsonResult,
 )
-from m3_django_compat import (
-    get_user_model,
-)
 from m3_ext.ui.shortcuts import (
     MessageBox,
 )
 
-from objectpack.actions import (
-    BaseAction,
-    BasePack,
-)
-
 from educommon import (
     ioc,
 )
@@ -63,6 +55,13 @@ from educommon.auth.simple_auth.models import (
 from educommon.m3 import (
     convert_validation_error_to,
 )
+from m3_django_compat import (
+    get_user_model,
+)
+from objectpack.actions import (
+    BaseAction,
+    BasePack,
+)
 
 
 class AuthPack(BasePack):
@@ -174,7 +173,7 @@ class LoginAction(BaseAction):
 
         err_msg = self.parent.login_checker.check(request, username, password)
 
-        if not request.is_ajax():
+        if not request.headers.get('x-requested-with') == 'XMLHttpRequest':
             result = HttpResponseRedirect('/')
         elif err_msg:
             result = PreJsonResult(
@@ -378,7 +377,7 @@ class LogoutAction(BaseAction):
     def run(self, request, context):
         auth.logout(request)
 
-        if request.is_ajax():
+        if request.headers.get('x-requested-with') == 'XMLHttpRequest':
             return PreJsonResult({})
         else:
             return http.HttpResponseRedirect('/')
