@@ -1,10 +1,5 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-
-class DefaultPasswordValidator(object):
-
-    u"""Валидация пароля."""
+class DefaultPasswordValidator:
+    """Валидация пароля."""
 
     _validators = []
 
