@@ -1,31 +1,41 @@
-# coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from datetime import (
+    date,
+    datetime,
+)
 
-from datetime import date
-from datetime import datetime
+from django.core.exceptions import (
+    NON_FIELD_ERRORS,
+    ValidationError,
+)
+from django.db import (
+    models,
+)
+from django.db.models.query_utils import (
+    Q,
+)
+from m3_django_compat import (
+    Manager,
+    ModelOptions,
+)
 
-from django.core.exceptions import NON_FIELD_ERRORS
-from django.core.exceptions import ValidationError
-from django.db import models
-from django.db.models.query_utils import Q
-from m3_django_compat import Manager
-from m3_django_compat import ModelOptions
-from six.moves import zip
-import six
-
-from educommon import Undefined
-from educommon.utils import is_ranges_intersected
-from educommon.utils.date import date_range_to_str
+from educommon import (
+    Undefined,
+)
+from educommon.utils import (
+    is_ranges_intersected,
+)
+from educommon.utils.date import (
+    date_range_to_str,
+)
 
 
 class BaseIntervalMeta(models.base.ModelBase):
-
     """Базовый метакласс для примесей *IntervalMixin.
 
     Добавляет к создаваемой модели поля, содержащие границы интервала. Имена
     полей задаются в атрибуте interval_field_names.
     """
+
     # тип поля модели, определяется в потомке
     _interval_bound_field_type = None
 
@@ -52,42 +62,34 @@ class BaseIntervalMeta(models.base.ModelBase):
         return result
 
     def __new__(cls, name, bases, attrs):
-        if (
-            cls._mixin_stay(bases) and
-            (
-                # поля с границами интервала создаются только если модель не
-                # абстрактная.
-                'Meta' not in attrs or
-                not hasattr(attrs['Meta'], 'abstract') or
-                not attrs['Meta'].abstract
-            )
+        if cls._mixin_stay(bases) and (
+            # поля с границами интервала создаются только если модель не
+            # абстрактная.
+            'Meta' not in attrs or not hasattr(attrs['Meta'], 'abstract') or not attrs['Meta'].abstract
         ):
-            interval_field_names = cls.__get_attr(
-                'interval_field_names', attrs, bases, cls.interval_field_names
-            )
+            interval_field_names = cls.__get_attr('interval_field_names', attrs, bases, cls.interval_field_names)
 
             # Добавление полей, хранящих границы интервала
-            for field_name, verbose_name in zip(
-                interval_field_names, ('Начало интервала', 'Конец интервала')
-            ):
+            for field_name, verbose_name in zip(interval_field_names, ('Начало интервала', 'Конец интервала')):
                 field = cls.__get_attr(field_name, attrs, bases)
                 if field is Undefined:
                     attrs[field_name] = cls._interval_bound_field_type(
                         name=field_name,
-                        blank=True, null=True,
+                        blank=True,
+                        null=True,
                         verbose_name=verbose_name,
                     )
 
-        return super(BaseIntervalMeta, cls).__new__(cls, name, bases, attrs)
+        return super().__new__(cls, name, bases, attrs)
 
 
 class DateIntervalMeta(BaseIntervalMeta):
-
     """Метакласс для примеси DateIntervalMixin.
 
     Добавляет к создаваемой модели поля дат, содержащие границы интервала.
     Имена полей задаются в атрибуте interval_field_names.
     """
+
     # тип полей модели, которые будет созданы
     _interval_bound_field_type = models.DateField
     # названия полей по умолчанию
@@ -99,19 +101,16 @@ class DateIntervalMeta(BaseIntervalMeta):
 
         :rtype bool
         """
-        return (
-            'DateIntervalMixin' in globals() and
-            any(issubclass(base, DateIntervalMixin) for base in bases)
-        )
+        return 'DateIntervalMixin' in globals() and any(issubclass(base, DateIntervalMixin) for base in bases)
 
 
 class DateTimeIntervalMeta(BaseIntervalMeta):
-
     """Метакласс для примеси DateTimeIntervalMixin.
 
     Добавляет к создаваемой модели поля дат со временем, содержащие
     границы интервала. Имена полей задаются в атрибуте interval_field_names.
     """
+
     # тип полей модели, которые будет созданы
     _interval_bound_field_type = models.DateTimeField
     # названия полей по умолчанию
@@ -123,14 +122,10 @@ class DateTimeIntervalMeta(BaseIntervalMeta):
 
         :rtype bool
         """
-        return (
-            'DateTimeIntervalMixin' in globals() and
-            any(issubclass(base, DateTimeIntervalMixin) for base in bases)
-        )
+        return 'DateTimeIntervalMixin' in globals() and any(issubclass(base, DateTimeIntervalMixin) for base in bases)
 
 
 class BaseIntervalMixin(models.Model):
-
     """Базовый класс для примесей к моделям, добавляющих интервал дат.
 
     Содержит два поля: date_from (дата начала интервала) и date_to (дата
@@ -155,18 +150,17 @@ class BaseIntervalMixin(models.Model):
 
     Используется для проверки пересечения диапазонов.
     """
+
     @classmethod
     def get_current_date(cls):
         """Возвращает текущую дату.
 
         :rtype: datetime.datetime or datetime.date
         """
-        raise NotImplemented
+        raise NotImplementedError
 
     @classmethod
-    def get_date_in_intervals_filter(cls, day=None, lookup=None,
-                                     include_lower_bound=True,
-                                     include_upper_bound=True):
+    def get_date_in_intervals_filter(cls, day=None, lookup=None, include_lower_bound=True, include_upper_bound=True):
         """Возвращает фильтр для выборки записей по указанной дате.
 
         Условия фильтра включают записи, в интервал которых входит
@@ -215,6 +209,7 @@ class BaseIntervalMixin(models.Model):
             to_filter |= Q(**{to_lookup + '__isnull': True})
 
         result = from_filter & to_filter
+
         return result
 
     @classmethod
@@ -223,14 +218,9 @@ class BaseIntervalMixin(models.Model):
 
     @classmethod
     def get_intersection_daterange_filter(
-        cls,
-        date_begin=None,
-        date_end=None,
-        lookup=None,
-        include_lower_bound=True,
-        include_upper_bound=True
+        cls, date_begin=None, date_end=None, lookup=None, include_lower_bound=True, include_upper_bound=True
     ):
-        u"""Метод возвращает фильтр для выборки записей, попадающих в интервал.
+        """Метод возвращает фильтр для выборки записей, попадающих в интервал.
 
         Для проверки пересечения двух интервалов a и b необходимо и
         достаточно выполнения двух условий:
@@ -258,11 +248,7 @@ class BaseIntervalMixin(models.Model):
 
         .. code-block:: python
             :caption: Пример использования
-            query = model.objects.filter(
-                model.get_intersection_daterange_filter(
-                    date_begin, date_end
-                )
-            )
+            query = model.objects.filter(model.get_intersection_daterange_filter(date_begin, date_end))
 
         :params date_begin: Дата начала интервала.
         :type date_begin: datetime.datetime
@@ -295,9 +281,7 @@ class BaseIntervalMixin(models.Model):
         # Предполагается, что в интервалах дат дата окончания находится
         # справа по оси времени от даты начала или равна. Если будет наоборот,
         # то результат может оказаться не верным
-        assert date_end >= date_begin, (
-            u'Дата окончания должна быть больше или равна дате начала'
-        )
+        assert date_end >= date_begin, 'Дата окончания должна быть больше или равна дате начала'
 
         from_name, to_name = cls.interval_field_names
         if lookup is not None:
@@ -321,6 +305,7 @@ class BaseIntervalMixin(models.Model):
             to_filter |= Q(**{to_lookup + '__isnull': True})
 
         result = from_filter & to_filter
+
         return result
 
     def is_date_in_interval(self, day):
@@ -333,12 +318,19 @@ class BaseIntervalMixin(models.Model):
         assert isinstance(day, (date, datetime)), type(day)
         date_from, date_to = self.interval_range
         result = (
-            date_from is None and date_to is None or
-            date_from is None and date_to is not None and day <= date_to or
-            date_from is not None and date_to is None and day >= date_from or
-            date_from is not None and date_to is not None and
-            date_from <= day <= date_to
+            date_from is None
+            and date_to is None
+            or date_from is None
+            and date_to is not None
+            and day <= date_to
+            or date_from is not None
+            and date_to is None
+            and day >= date_from
+            or date_from is not None
+            and date_to is not None
+            and date_from <= day <= date_to
         )
+
         return result
 
     def is_intersected_with(self, date_from, date_to):
@@ -381,7 +373,7 @@ class BaseIntervalMixin(models.Model):
     def interval_dates_error_message(self):
         """Возвращает сообщение о неправильных границах интервала.
 
-        :rtype: unicode
+        :rtype: str
         """
         opts = ModelOptions(self)
 
@@ -390,6 +382,7 @@ class BaseIntervalMixin(models.Model):
             opts.get_field(date_from_name).verbose_name.capitalize(),
             opts.get_field(date_to_name).verbose_name.lower(),
         )
+
         return result
 
     def interval_intersected_error_message(self, others=None):
@@ -398,7 +391,7 @@ class BaseIntervalMixin(models.Model):
         :param others: Записи, с интервалами которых пересекается интервал
             данной записи.
 
-        :rtype: unicode
+        :rtype: str
         """
         return 'Интервал пересекается с другими записями'
 
@@ -409,9 +402,9 @@ class BaseIntervalMixin(models.Model):
 
         date_from = getattr(self, date_from_name)
 
-        prev_intervals = self.__class__.objects.filter(
-            **{'{}__lt'.format(date_to_name): date_from}
-        ).order_by('-{}'.format(date_to_name))
+        prev_intervals = self.__class__.objects.filter(**{'{}__lt'.format(date_to_name): date_from}).order_by(
+            '-{}'.format(date_to_name)
+        )
 
         return prev_intervals[0] if prev_intervals else None
 
@@ -456,9 +449,9 @@ class BaseIntervalMixin(models.Model):
 
         date_to = getattr(self, date_to_name)
 
-        next_intervals = self.__class__.objects.filter(
-            **{'{}__gt'.format(date_from_name): date_to}
-        ).order_by(date_from_name)
+        next_intervals = self.__class__.objects.filter(**{'{}__gt'.format(date_from_name): date_to}).order_by(
+            date_from_name
+        )
 
         return next_intervals[0] if next_intervals else None
 
@@ -467,28 +460,20 @@ class BaseIntervalMixin(models.Model):
         errors = {}
 
         try:
-            super(BaseIntervalMixin, self).clean()
+            super().clean()
         except ValidationError as error:
             errors = error.update_error_dict(errors)
 
         date_from, date_to = self.interval_range
 
         # Дата начала интервала должна быть раньше даты окончания
-        if (
-            date_from is not None and
-            date_to is not None and
-            date_from > date_to
-        ):
-            errors.setdefault(NON_FIELD_ERRORS, []).append(
-                self.interval_dates_error_message()
-            )
+        if date_from is not None and date_to is not None and date_from > date_to:
+            errors.setdefault(NON_FIELD_ERRORS, []).append(self.interval_dates_error_message())
         else:
             # Проверка пересения интервалов
             others = self.get_intersected_query()
             if others:
-                errors.setdefault(NON_FIELD_ERRORS, []).append(
-                    self.interval_intersected_error_message(others)
-                )
+                errors.setdefault(NON_FIELD_ERRORS, []).append(self.interval_intersected_error_message(others))
 
         if errors:
             raise ValidationError(errors)
@@ -497,10 +482,7 @@ class BaseIntervalMixin(models.Model):
         abstract = True
 
 
-class DateIntervalMixin(
-    six.with_metaclass(DateIntervalMeta, BaseIntervalMixin)
-):
-
+class DateIntervalMixin(BaseIntervalMixin, metaclass=DateIntervalMeta):
     """Примесь к моделям, добавляющяя интервал дат.
 
     Содержит два поля: date_from (дата начала интервала) и date_to (дата
@@ -537,10 +519,7 @@ class DateIntervalMixin(
         abstract = True
 
 
-class DateTimeIntervalMixin(
-    six.with_metaclass(DateTimeIntervalMeta, BaseIntervalMixin)
-):
-
+class DateTimeIntervalMixin(BaseIntervalMixin, metaclass=DateTimeIntervalMeta):
     """Примесь к моделям, добавляющия интервал дат со временем.
 
     Содержит два поля: date_from (дата начала интервала) и date_to (дата
@@ -578,7 +557,6 @@ class DateTimeIntervalMixin(
 
 
 class ActualObjectsManager(Manager):
-
     """Менеджер для интервальной модели.
 
     Отфильтровывает все объекты, в интервал которых входит текущая дата.
@@ -587,9 +565,7 @@ class ActualObjectsManager(Manager):
     def contribute_to_class(self, model, name):
         assert issubclass(model, BaseIntervalMixin), type(model)
 
-        super(ActualObjectsManager, self).contribute_to_class(model, name)
+        super().contribute_to_class(model, name)
 
     def get_queryset(self):
-        return super(ActualObjectsManager, self).get_queryset().filter(
-            self.model.get_date_in_intervals_filter()
-        )
+        return super().get_queryset().filter(self.model.get_date_in_intervals_filter())
