@@ -1,8 +1,9 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
+from django.conf import (
+    settings,
+)
+from django.core.exceptions import (
+    ImproperlyConfigured,
+)
 
 
 try:
@@ -11,7 +12,7 @@ try:
     VIS_USER = settings.ATCFS_CONF['VIS_USER']
     SECRET_KEY = settings.ATCFS_CONF['SECRET_KEY']
 except (AttributeError, KeyError):
-    msg = u'settings.ATCFS_CONF is improperly configured.'
+    msg = 'settings.ATCFS_CONF is improperly configured.'
     raise ImproperlyConfigured(msg)
 
 # Constants
