@@ -1,20 +1,19 @@
-# coding: utf-8
-from __future__ import absolute_import
-from __future__ import print_function
-
-from datetime import datetime
 import re
 import uuid
+from datetime import (
+    datetime,
+)
 
-from django.core.exceptions import ValidationError
-from six.moves import filter
-from six.moves import range
-from xlrd.xldate import XLDateAmbiguous
-from xlrd.xldate import XLDateBadDatemode
-from xlrd.xldate import XLDateNegative
-from xlrd.xldate import XLDateTooLarge
-import six
 import xlrd
+from django.core.exceptions import (
+    ValidationError,
+)
+from xlrd.xldate import (
+    XLDateAmbiguous,
+    XLDateBadDatemode,
+    XLDateNegative,
+    XLDateTooLarge,
+)
 
 
 SUBTREE_CAN_BE_EMPTY = '__grp_can_be_empty'
@@ -31,10 +30,12 @@ _SPECIAL_KEYS = (
 
 
 def _fold(tree, path='', group=None):
-    """
+    """Свертка словаря-дерева.
+
     Свертка словаря-дерева в список пар (путь, значение, группа|None)
-    ("группа", это uuid, для группировки значений одного поддерева)
+    ("группа", это uuid, для группировки значений одного поддерева).
     """
+
     if not isinstance(tree, dict):
         return [(path, tree, group)]
 
@@ -42,20 +43,21 @@ def _fold(tree, path='', group=None):
         if tree.get(SUBTREE_CAN_BE_EMPTY, False):
             group = uuid.uuid4()
 
-    path = ('%s/%%s' % path) if path else '%s'
+    path = f'{path}/{{0}}' if path else '{0}'
+
     res = []
-    for key, val in six.iteritems(tree):
+    for key, val in tree.items():
         if key in _SPECIAL_KEYS:
             continue
-        key = path % key
+
+        key = path.format(key)
         res.extend(_fold(val, key, group))
+
     return res
 
 
 def _unfold(lst):
-    """
-    Развертка списка пар (путь, значение) в словарь-дерево
-    """
+    """Развертка списка пар (путь, значение) в словарь-дерево."""
     res = {}
 
     def set_val(res, path, val):
@@ -80,9 +82,7 @@ MATCH_IF_CONTAINS = 3
 
 
 def _is_match(value, pattern, match_type=MATCH_IF_EXACT):
-    """
-    Проверка на совпадение значения с образцом
-    """
+    """Проверка на совпадение значения с образцом."""
     pattern = pattern.upper()
     value = value.upper()
 
@@ -90,29 +90,26 @@ def _is_match(value, pattern, match_type=MATCH_IF_EXACT):
         return value.find(pattern) >= 0
     elif match_type == MATCH_IF_STARTS_WITH:
         return value.startswith(pattern)
+
     return value == pattern
 
 
 class CellValueError(Exception):
-    """
-    Исключение для неверного значения ячейки
-    """
+    """Исключение для неверного значения ячейки."""
+
     pass
 
 
 class EmptyObligatoryCellError(CellValueError):
-    """
-    Исключение для неверного значения ячейки
-    """
+    """Исключение для неверного значения ячейки."""
+
     def __init__(self, message=None):
-        super(EmptyObligatoryCellError, self).__init__(
-            message or u'Ячейка не может быть пустой!')
+        super().__init__(message or 'Ячейка не может быть пустой!')
 
 
-class BaseCell(object):
-    """
-    Прототип парсера ячейки
-    """
+class BaseCell:
+    """Прототип парсера ячейки."""
+
     _default = _NO_DEFAULT
 
     def __init__(self, default=_NO_DEFAULT):
@@ -125,15 +122,11 @@ class BaseCell(object):
         return (value, False)
 
     def _parse(self, value):
-        """
-        Разбор значения
-        """
-        raise NotImplementedError(u'Прототип не используется напрямую!')
+        """Разбор значения."""
+        raise NotImplementedError('Прототип не используется напрямую!')
 
     def from_cell(self, sheet, row, col):
-        """
-        Получение значения из ячейки в виде (значение, is_default)
-        """
+        """Получение значения из ячейки в виде (значение, is_default)."""
         try:
             value = sheet.cell(row, col).value
         except IndexError:
@@ -141,35 +134,31 @@ class BaseCell(object):
                 raise EmptyObligatoryCellError()
             return self.default()
 
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             value = value.strip()
 
-        if value is None or value == "":
+        if value is None or value == '':
             if self.is_obligatory():
                 raise EmptyObligatoryCellError()
             return self.default()
 
-        return self._parse(six.text_type(value))
+        return self._parse(str(value))
 
     def is_obligatory(self):
         return self._default == _NO_DEFAULT
 
 
 class StringCell(BaseCell):
-    """
-    Строковая ячейка
-    """
+    """Строковая ячейка."""
 
-    MSG_RECORD_TRUNCATED = (
-        u'Превышена максимально допустимая длина записи. Запись сокращена'
-    )
+    MSG_RECORD_TRUNCATED = 'Превышена максимально допустимая длина записи. Запись сокращена'
 
-    DEFAULT_RE_MESSAGE = u'Неправильный формат записи'
+    DEFAULT_RE_MESSAGE = 'Неправильный формат записи'
 
     def __init__(
-            self, default=_NO_DEFAULT, max_length=None, regex=None,
-            validator=None, error_message=None, verbose=True):
-        u"""Строковая ячейка.
+        self, default=_NO_DEFAULT, max_length=None, regex=None, validator=None, error_message=None, verbose=True
+    ):
+        """Строковая ячейка.
 
         :param int max_length: Максимальная длина строки.
         :param regex: Регулярное выражение для проверки значения.
@@ -179,7 +168,7 @@ class StringCell(BaseCell):
         """
         assert max_length is None or isinstance(max_length, int)
 
-        super(StringCell, self).__init__(default)
+        super().__init__(default)
 
         self._max_length = max_length
         self._verbose = verbose
@@ -190,10 +179,10 @@ class StringCell(BaseCell):
         self.message = None
 
     def set_mgs(self, msg):
-        self.message = self.message or u'' + msg
+        self.message = self.message or '' + msg
 
     def _validate(self, value):
-        u"""Выплоняет проверку по регулярному выражению.
+        """Выплоняет проверку по регулярному выражению.
 
         Если проверка не пройдена и ячейка обязательна, то райзит
         CellValueError. Если ячейка не обязательна, то она пропускается и
@@ -206,7 +195,7 @@ class StringCell(BaseCell):
                 if self._default is None:
                     if self._verbose:
                         self.set_mgs(message)
-                    value = u''
+                    value = ''
 
                 elif self._default is _NO_DEFAULT:
                     raise CellValueError(message)
@@ -218,25 +207,23 @@ class StringCell(BaseCell):
             except ValidationError as err:
                 if self._default is None:
                     if self._verbose:
-                        self.set_mgs(
-                            u', '.join(err.messages)
-                        )
-                    value = u''
+                        self.set_mgs(', '.join(err.messages))
+                    value = ''
 
                 elif self._default is _NO_DEFAULT:
-                    raise CellValueError(u', '.join(err.messages))
+                    raise CellValueError(', '.join(err.messages))
 
         return value
 
     def _truncate(self, value):
-        u"""Обрезает строку до указанной в self._max_length длины."""
-        new_value = value[:self._max_length]
+        """Обрезает строку до указанной в self._max_length длины."""
+        new_value = value[: self._max_length]
         if self._verbose and new_value != value:
             self.set_mgs(self.MSG_RECORD_TRUNCATED)
+
         return new_value
 
     def _parse(self, value):
-
         self.message = None
 
         if value.endswith('.0'):
@@ -251,17 +238,14 @@ class StringCell(BaseCell):
         if self._regex is not None or self._validator is not None:
             value = self._validate(value)
 
-        return self.result(six.text_type(value))
+        return self.result(str(value))
 
 
 class MaybeStringCell(StringCell):
-    """
-    Строка или None
-    """
-    def __init__(
-            self, default=None, max_length=None, regex=None,
-            validator=None, error_message=None, verbose=True):
-        u"""Строка или None.
+    """Строка или None."""
+
+    def __init__(self, default=None, max_length=None, regex=None, validator=None, error_message=None, verbose=True):
+        """Строка или None.
 
         :param int max_length: Максимальная длина строки.
         :param regex: Регулярное выражение для проверки значения.
@@ -269,33 +253,36 @@ class MaybeStringCell(StringCell):
         :param error_message: Сообщение в случае провала проверки.
         :param bool verbose: Записывать ли сообщения в лог.
         """
-        super(MaybeStringCell, self).__init__(
-            default=None, max_length=max_length, regex=regex,
-            validator=validator, error_message=error_message, verbose=verbose)
+        super().__init__(
+            default=None,
+            max_length=max_length,
+            regex=regex,
+            validator=validator,
+            error_message=error_message,
+            verbose=verbose,
+        )
 
 
 class RawCell(BaseCell):
+    """Сырая строковая ячейка "как есть".
+
+    В том числе с добавками Excel в зависимости от типа ячейки.
     """
-    Сырая строковая ячейка "как есть",
-    в том числе с добавками Excel в зависимости
-    от типа ячейки
-    """
+
     def _parse(self, value):
-        return self.result(six.text_type(value))
+        return self.result(str(value))
 
 
 class MaybeRawCell(RawCell):
-    """
-    Сырая строковая ячейка "как есть" или None
-    """
+    """Сырая строковая ячейка "как есть" или None."""
+
     def __init__(self):
-        super(MaybeRawCell, self).__init__(default=None)
+        super().__init__(default=None)
 
 
 class IntCell(BaseCell):
-    """
-    Integer ячейка
-    """
+    """Integer ячейка."""
+
     def _parse(self, value):
         try:
             result = int(value)
@@ -303,73 +290,62 @@ class IntCell(BaseCell):
             try:
                 result = int(float(value))
             except (TypeError, ValueError):
-                raise CellValueError(
-                    u'Число имеет неверный формат! "%s"' % value)
+                raise CellValueError(f'Число имеет неверный формат! "{value}"')
         return self.result(result)
 
 
 class MaybeIntCell(IntCell):
-    """
-    Int или None
-    """
+    """Int или None."""
+
     def __init__(self):
-        super(MaybeIntCell, self).__init__(default=None)
+        super().__init__(default=None)
 
 
 class MaybeNonNegativeIntCell(MaybeIntCell):
+    """Не отрицательное целое число или None.
+
+    Не отбрасывает дробную часть (если она больше 0) и райзит ошибку.
     """
-    Не отрицательное целое число или None
-    Не отбрасывает дробную часть (если она больше 0) и райзит ошибку
-    """
+
     def _parse(self, value):
-        result, _ = super(MaybeIntCell, self)._parse(value)
+        result, _ = super()._parse(value)
+
         if result < 0:
-            raise CellValueError(
-                u'Число должно быть не меньше нуля! "%s"' % value)
+            raise CellValueError(f'Число должно быть не меньше нуля! "{value}"')
         if float(value) != float(int(float(value))):
-            raise CellValueError(
-                u'Число должно быть целым! "%s"' % value)
+            raise CellValueError(f'Число должно быть целым! "{value}"')
         return self.result(result)
 
 
 class BooleanCell(BaseCell):
-    """
-    Bool-ячейка, получает True при совпадении с паттерном
-    """
-    def __init__(self, default=_NO_DEFAULT,
-                 pattern=None, match_type=MATCH_IF_EXACT):
-        """
-        Если паттерн опущен (или None), то результат будет True при любой
-        значащей строке в ячейке.
-        """
+    """Bool-ячейка, получает True при совпадении с паттерном."""
+
+    def __init__(self, default=_NO_DEFAULT, pattern=None, match_type=MATCH_IF_EXACT):
+        """Если паттерн опущен (или None), то результат будет True при любой значащей строке в ячейке."""
+        super().__init__(default=default)
 
-        super(BooleanCell, self).__init__(default=default)
         self.pattern = pattern
         self.match_type = match_type
 
     def _parse(self, value):
         if self.pattern is None:
-            return self.result(
-                bool(value.strip()))
+            return self.result(bool(value.strip()))
         return self.result(_is_match(value, self.pattern, self.match_type))
 
 
 class MaybeTrueCell(BooleanCell):
-    """
-    Bool-ячейка, которая получает значение True при успешном совападении
-    паттерна
-    """
+    """Bool-ячейка, которая получает значение True при успешном совпадении паттерна."""
+
     def __init__(self, default=None, pattern=None, match_type=MATCH_IF_EXACT):
+        """Если паттерн опущен (или None), то результат будет True при любой значащей строке в ячейке.
+
+        Параметр default игнорируется (всегда равен False).
         """
-        Если паттерн опущен (или None), то результат будет True при любой
-        значащей строке в ячейке.
-        Параметр default игнорируется (всегда равет False)
-        """
-        super(MaybeTrueCell, self).__init__(
-            default=False, pattern=pattern, match_type=match_type)
+        super().__init__(default=False, pattern=pattern, match_type=match_type)
 
     def _parse(self, value):
-        result, _ = super(MaybeTrueCell, self)._parse(value)
+        result, _ = super()._parse(value)
+
         if result:
             return self.result(True)
         else:
@@ -377,21 +353,18 @@ class MaybeTrueCell(BooleanCell):
 
 
 class MaybeFalseCell(BooleanCell):
-    """
-    Bool-ячейка, которая получает значение False при успешном совападении
-    паттерна
-    """
+    """Bool-ячейка, которая получает значение False при успешном совпадении паттерна."""
+
     def __init__(self, default=None, pattern=None, match_type=MATCH_IF_EXACT):
+        """Если паттерн опущен (или None), то результат будет False при любой значащей строке в ячейке.
+
+        Параметр default игнорируется (всегда равен True).
         """
-        Если паттерн опущен (или None), то результат будет False при любой
-        значащей строке в ячейке.
-        Параметр default игнорируется (всегда равет True)
-        """
-        super(MaybeFalseCell, self).__init__(
-            default=True, pattern=pattern, match_type=match_type)
+        super().__init__(default=True, pattern=pattern, match_type=match_type)
 
     def _parse(self, value):
-        result, _ = super(MaybeFalseCell, self)._parse(value)
+        result, _ = super()._parse(value)
+
         if result:
             return self.result(False)
         else:
@@ -399,16 +372,14 @@ class MaybeFalseCell(BooleanCell):
 
 
 class EnumCell(BaseCell):
-    """
-    Ячейка, которая может принимать одно из заданных значений
-    """
-    def __init__(self, default=_NO_DEFAULT, choices=None,
-                 match_type=MATCH_IF_EXACT, blank_values=None):
-        """
-        choices - список вариантов вида (pattern, value)
-        """
-        assert len(choices) >= 2, u'Должно быть указано хотя бы 2 варианта!'
-        super(EnumCell, self).__init__(default=default)
+    """Ячейка, которая может принимать одно из заданных значений."""
+
+    def __init__(self, default=_NO_DEFAULT, choices=None, match_type=MATCH_IF_EXACT, blank_values=None):
+        """choices - список вариантов вида (pattern, value)."""
+        assert len(choices) >= 2, 'Должно быть указано хотя бы 2 варианта!'
+
+        super().__init__(default=default)
+
         self.choices = choices
         self.match_type = match_type
         self.blank_values = blank_values
@@ -416,7 +387,7 @@ class EnumCell(BaseCell):
     def _is_blank(self, value):
         if self.blank_values is not None:
             for blank_value in self.blank_values:
-                if value.lower() == six.text_type(blank_value).lower():
+                if value.lower() == str(blank_value).lower():
                     return True
         return False
 
@@ -426,15 +397,14 @@ class EnumCell(BaseCell):
         for result, pattern in self.choices:
             if _is_match(value, pattern, self.match_type):
                 return self.result(result)
-        raise CellValueError(u'Недопустимое значение!')
+        raise CellValueError('Недопустимое значение!')
 
 
-WRONG_DATE_FORMAT_MSG = u'Неправильный формат даты!'
+WRONG_DATE_FORMAT_MSG = 'Неправильный формат даты!'
 
 
 class DateCell(BaseCell):
-
-    u"""Ячейка даты."""
+    """Ячейка даты."""
 
     # различные возможные допустимые форматы дат
     possible_date_formats = ('%d.%m.%Y', '%Y.%m.%d', '%d.%m.%y')
@@ -443,11 +413,10 @@ class DateCell(BaseCell):
         result = None
         try:
             result = datetime(*xlrd.xldate_as_tuple(float(value), 0))
-        except (XLDateNegative, XLDateAmbiguous, XLDateTooLarge,
-                XLDateBadDatemode):
+        except (XLDateNegative, XLDateAmbiguous, XLDateTooLarge, XLDateBadDatemode):
             raise CellValueError(WRONG_DATE_FORMAT_MSG)
         except ValueError:
-            value = six.text_type(value).strip()[:10]
+            value = str(value).strip()[:10]
             value = value.replace('/', '.').replace('-', '.')
             if any(x not in '0123456789.' for x in value):
                 raise CellValueError(WRONG_DATE_FORMAT_MSG)
@@ -465,24 +434,18 @@ class DateCell(BaseCell):
 
 
 class MaybeDateCell(DateCell):
-    """
-    Date или None
-    """
+    """Date или None."""
+
     def __init__(self):
-        super(MaybeDateCell, self).__init__(default=None)
+        super().__init__(default=None)
 
 
-class DynamicStartRow(object):
-    """
-    Автоматический поиск начала таблицы по ее заголовкам ее столбцов
-    """
+class DynamicStartRow:
+    """Автоматический поиск начала таблицы по ее заголовкам ее столбцов."""
 
-    def __init__(self, table_headers,
-                 order_sensetive=True,
-                 case_sensitive=False,
-                 search_area=[(0, 0), (50, 50)]):
+    def __init__(self, table_headers, order_sensetive=True, case_sensitive=False, search_area=[(0, 0), (50, 50)]):
         """
-        :param list table_headers: Список заголовков: [u'Фамилия' u'Имя']
+        :param list table_headers: Список заголовков: ['Фамилия' 'Имя']
         :param bool order_sensetive: Учитывать порядок списка table_headers
         :param bool case_sensitive: Учитывать регистр при сопоставлении
         :param list search_area: Область в которой будет производиться поиск
@@ -502,7 +465,6 @@ class DynamicStartRow(object):
             self.table_headers = [s.upper() for s in table_headers]
 
     def find_pos(self, sheet):
-
         max_row = min(self.max_row, sheet.nrows)
         max_col = min(self.max_col, sheet.ncols)
 
@@ -511,14 +473,13 @@ class DynamicStartRow(object):
             for col in range(self.min_col, max_col):
                 val = sheet.cell(row, col).value
 
-                if isinstance(val, six.string_types) and not self.case_sensitive:
+                if isinstance(val, str) and not self.case_sensitive:
                     val = val.strip().upper()
 
                 if val in self.table_headers:
                     matched.setdefault(val, col)
 
             if len(matched) == len(self.table_headers):
-
                 cols_nums = [matched[h] for h in self.table_headers]
                 if self.order_sensetive and sorted(cols_nums) != cols_nums:
                     continue
@@ -526,22 +487,18 @@ class DynamicStartRow(object):
                 return row, min(cols_nums)
 
     def find_row(self, sheet):
-
         pos = self.find_pos(sheet)
         if pos:
             row, col = pos
             return row
 
 
-class SimpleColumnMatcher(object):
-    """
-    Класс сопоставления столбцов таблицы
-    """
+class SimpleColumnMatcher:
+    """Класс сопоставления столбцов таблицы."""
 
-    def __init__(self, column_name, unique_check=False,
-                 strip=True, case_sensitive=False, replacer=None):
+    def __init__(self, column_name, unique_check=False, strip=True, case_sensitive=False, replacer=None):
         """
-        :param unicode column_name: Название столбца
+        :param str column_name: Название столбца
         :param bool unique_check: Нужно ли проверять на то, чтобы данный
                 matcher совпал только с одним столбцом таблицы
         :param bool strip: Нужно ли удалять крайние пробельные символы
@@ -549,7 +506,7 @@ class SimpleColumnMatcher(object):
         :param callable replacer: Функция для доп. настройки значения.
             Например:
             замена нескольких пробелов одним: lambda s: re.sub(r'\s+', ' ', s)
-            замена ё на е: lambda s: s.replace(u'ё', u'е')
+            замена ё на е: lambda s: s.replace('ё', 'е')
         """
         self.column_name = column_name
         self._unique_check = unique_check
@@ -560,7 +517,7 @@ class SimpleColumnMatcher(object):
         self.replacer = replacer
 
     def get_column_name(self):
-        """Возвращает название столбца"""
+        """Возвращает название столбца."""
         return self.column_name
 
     @property
@@ -568,8 +525,8 @@ class SimpleColumnMatcher(object):
         return self._unique_check
 
     def _prepare_cell_value(self, cell_value):
-        """Подготовка значения с учетом флагов настроек"""
-        cell_value = six.text_type(cell_value)
+        """Подготовка значения с учетом флагов настроек."""
+        cell_value = str(cell_value)
         if self.strip:
             cell_value = cell_value.strip()
 
@@ -582,37 +539,34 @@ class SimpleColumnMatcher(object):
         return cell_value
 
     def match(self, cell_value):
-        """
-        Проверка: отвечает ли значение в cell_value
-        требуемому названию столбца
-        """
+        """Проверка: отвечает ли значение в cell_value требуемому названию столбца."""
 
         column_name = self.column_name
         if not self.case_sensitive:
             column_name = column_name.upper()
 
         cell_value = self._prepare_cell_value(cell_value)
+
         return cell_value == column_name
 
 
 class RegexColumnMatcher(SimpleColumnMatcher):
-    """
-    Сопоставление столбцов по регулярному выражению
-    """
+    """Сопоставление столбцов по регулярному выражению."""
 
     def __init__(self, column_name, regex, **kwargs):
-
-        if isinstance(regex, six.string_types):
+        if isinstance(regex, str):
             flags = re.UNICODE
             if not kwargs.get('case_sensitive'):
                 flags |= re.IGNORECASE
 
             regex = re.compile(regex, flags)
         self.regex = regex
-        super(RegexColumnMatcher, self).__init__(column_name, **kwargs)
+
+        super().__init__(column_name, **kwargs)
 
     def match(self, cell_value):
         cell_value = self._prepare_cell_value(cell_value)
+
         return bool(self.regex.search(cell_value))
 
 
@@ -620,23 +574,23 @@ class RegexColumnMatcher(SimpleColumnMatcher):
 # XLSLoader
 # =============================================================================
 
-class XLSLoader(object):
-    """
-    Загрузчик xls-файла с разбором
-    """
+
+class XLSLoader:
+    """Загрузчик xls-файла с разбором."""
+
     config = {}
 
     """
     ..code::
 
         config = {
-            u'заголовок листа': {
+            'заголовок листа': {
                'объект_1': {
                    #SUBTREE_CAN_BE_EMPTY: True,  # вся группа м.б. пустой
-                   'поле_объекта': (u'шапка столбца', парсер_ячейки),
-                   'другое_поле_объекта': (u'шапка столбца', парсер_ячейки),
+                   'поле_объекта': ('шапка столбца', парсер_ячейки),
+                   'другое_поле_объекта': ('шапка столбца', парсер_ячейки),
                },
-               'просто параметр': (u'шапка столбца', парсер_ячейки)
+               'просто параметр': ('шапка столбца', парсер_ячейки)
             # начинать разбор с указанной строки:
             #START_ROW: 0,
             # все строки выше START_ROW передаются в HEADER_PARSER
@@ -653,7 +607,7 @@ class XLSLoader(object):
 
     XLS_POS = '__xls_pos__'
 
-    __RESERVED_SHEET = u'СПРАВОЧНИК'
+    __RESERVED_SHEET = 'СПРАВОЧНИК'
 
     def __init__(self, memory_mapped_file, config=None):
         self._file = memory_mapped_file
@@ -666,14 +620,10 @@ class XLSLoader(object):
         self._row_errors_log = {}
         self._log_change_flag = False
 
-        self._book = xlrd.open_workbook(
-            file_contents=memory_mapped_file.read())
+        self._book = xlrd.open_workbook(file_contents=memory_mapped_file.read())
 
-        if not all((
-            self._file,
-            self._book.nsheets > 0
-        )):
-            self._log(u"Не удалось загрузить файл!")
+        if not all((self._file, self._book.nsheets > 0)):
+            self._log('Не удалось загрузить файл!')
             self._book = None
             raise ValueError('See loader log')
 
@@ -682,7 +632,7 @@ class XLSLoader(object):
         self._start_rows, self._end_rows = {}, {}
         self._header_parsers = {}
         self._flat_config = {}
-        for k, v in six.iteritems(self.config):
+        for k, v in self.config.items():
             try:
                 k = k.strip().upper()
             except AttributeError:
@@ -695,30 +645,23 @@ class XLSLoader(object):
                 HEADER_PARSER,
                 # парсер строки шапки листа по-умолчанию:
                 # накапливает в список непустые ячейки
-                lambda x: list(filter(bool, x))
+                lambda x: list(filter(bool, x)),
             )
             self._flat_config[k] = _fold(v)
 
         if self._XLSLoader__RESERVED_SHEET in self._flat_config:
-            raise AssertionError(
-                u'Название листа "%s" зарезервировано!' %
-                self._XLSLoader__RESERVED_SHEET
-            )
+            raise AssertionError(f'Название листа "{self._XLSLoader__RESERVED_SHEET}" зарезервировано!')
 
         self._loaded_data = {}
         self._headers = {}
 
     def _log_common_error(self, *items):
-        """
-        Запись в основной лог ошибок
-        """
+        """Запись в основной лог ошибок."""
         self._log_change_flag = True
         self._common_log.extend(items)
 
     def _log_row_error(self, xls_pos, *items):
-        """
-        Добавление ошибки в строке
-        """
+        """Добавление ошибки в строке."""
         self._log_change_flag = True
         self._row_errors_log.setdefault(xls_pos, []).extend(items)
 
@@ -745,9 +688,7 @@ class XLSLoader(object):
         return self._headers
 
     def load(self):
-        """
-        Загрузка листа по дескриптору колонок строки
-        """
+        """Загрузка листа по дескриптору колонок строки."""
         if self._book is None:
             return False
 
@@ -769,9 +710,8 @@ class XLSLoader(object):
             except KeyError:
                 if sheet_name == self._XLSLoader__RESERVED_SHEET:
                     continue
-                for k, v in six.iteritems(self._flat_config):
-                    if (isinstance(k, int) and (sheet_num + 1) == k) or (
-                            isinstance(k, tuple) and (sheet_num + 1) in k):
+                for k, v in self._flat_config.items():
+                    if (isinstance(k, int) and (sheet_num + 1) == k) or (isinstance(k, tuple) and (sheet_num + 1) in k):
                         parsers = v
                         parser_key = k
                         break
@@ -781,22 +721,14 @@ class XLSLoader(object):
                     else:
                         expected_sheets = (
                             key
-                            for key in map(
-                                lambda x: six.text_type(x).capitalize(),
-                                self._flat_config
-                            )
+                            for key in map(lambda x: str(x).capitalize(), self._flat_config)
                             if key != self.ANY_SHEET
                         )
 
                         self._log_row_error(
                             (sheet.name, sheet_num + 1, 0),
-                            u'Неверное название листа №%s: %s.\n'
-                            u'Ожидаемые названия листов: %s' %
-                            (
-                                sheet_num + 1,
-                                sheet.name,
-                                u', '.join(expected_sheets)
-                            ),
+                            f'Неверное название листа №{sheet_num + 1}: {sheet.name}.\n'
+                            f'Ожидаемые названия листов: {", ".join(expected_sheets)}',
                         )
                         continue
 
@@ -811,25 +743,20 @@ class XLSLoader(object):
                 sheet = self._book.sheet_by_index(0)
                 start_row = start_row.find_row(sheet)
                 if start_row is None:
-                    self._log_common_error(u'Таблица не найдена')
+                    self._log_common_error('Таблица не найдена')
                     continue
 
             header_data = self._headers.setdefault(parser_key, [])
             for row in range(0, start_row):
                 # парсеру заголовка передаётся итератор ячеек по строкам
-                header_data.append(
-                    header_parser((
-                        sheet.cell(row, i).value for i in range(sheet.ncols)
-                    ))
-                )
+                header_data.append(header_parser((sheet.cell(row, i).value for i in range(sheet.ncols))))
 
             # разбор шапки листа
             col_parsers = []
             errors = []
 
             for path, (col_mather, parser), grp in parsers:
-
-                if isinstance(col_mather, six.string_types):
+                if isinstance(col_mather, str):
                     col_mather = SimpleColumnMatcher(col_mather)
                 # в шапке могут быть целочисленные ячейки
                 elif isinstance(col_mather, int):
@@ -848,39 +775,28 @@ class XLSLoader(object):
                         break
 
                     if col_mather.match(cell_value):
-                        matched_cols.append(
-                            (col, six.text_type(cell_value).strip())
-                        )
+                        matched_cols.append((col, str(cell_value).strip()))
 
                 if not matched_cols:
                     if parser.is_obligatory():
                         errors.append(
-                            u'На листе "%s" (%s) отсутствует столбец "%s", '
-                            u'необходимый для импорта' % (
-                                sheet_name, sheet_num + 1, column_name
-                            )
+                            f'На листе "{sheet_name}" ({sheet_num + 1}) отсутствует столбец "{column_name}", '
+                            'необходимый для импорта'
                         )
 
                 elif col_mather.unique_check and len(matched_cols) > 1:
+                    column_names = ', '.join(f'"{x[1]}"' for x in matched_cols)
                     errors.append(
-                        u'На листе "%s" (%s) присутствуют взаимоисключающие '
-                        u'столбцы: %s.' % (
-                            sheet_name, sheet_num + 1,
-                            u', '.join(u'"%s"' % x[1] for x in matched_cols)
-                        )
+                        f'На листе "{sheet_name}" ({sheet_num + 1}) присутствуют взаимоисключающие '
+                        f'столбцы: {column_names}.'
                     )
                 else:
                     col_pos, real_column_name = matched_cols[0]
-                    col_parsers.append(
-                        (col_pos, real_column_name, path, parser, grp)
-                    )
+                    col_parsers.append((col_pos, real_column_name, path, parser, grp))
 
             if errors:
                 for error in errors:
-                    self._log_row_error(
-                        (sheet.name, sheet_num + 1, start_row + 1),
-                        error
-                    )
+                    self._log_row_error((sheet.name, sheet_num + 1, start_row + 1), error)
                 continue
 
             # список результатов связанный с именем листа
@@ -901,19 +817,15 @@ class XLSLoader(object):
                 filled_cells_counts = {}
 
                 def inc_counter(grp):
-                    filled_cells_counts[grp] = (
-                        filled_cells_counts.get(grp, 0) + 1
-                    )
+                    filled_cells_counts[grp] = filled_cells_counts.get(grp, 0) + 1
 
                 row_errors = {}
 
                 def add_err(grp, title, err):
-                    row_errors.setdefault(grp, set()).add(
-                        u'Cтолбец "%s": %s' % (title, err)
-                    )
+                    row_errors.setdefault(grp, set()).add(f'Cтолбец "{title}": {err}')
 
                 def add_warn(grp, title, msg):
-                    message = u'Cтолбец "%s": %s' % (title, msg)
+                    message = f'Cтолбец "{title}": {msg}'
                     self._log_row_error(xls_pos, *[message])
 
                 groups = set()
@@ -968,7 +880,7 @@ class XLSLoader(object):
         non_empty = any(self._loaded_data.values())
 
         if not non_empty and not self._row_errors_log:
-            self._log_common_error(u'Файл пуст!')
+            self._log_common_error('Файл пуст!')
 
         # результат будет True, если есть хоть одна загруженная строка
         return non_empty
@@ -979,15 +891,14 @@ class XLSLoader(object):
         Преобразует словарь-лог ошибок строк в отсортированный список строк
         """
         result = []
-        for pos, lines in sorted(
-            log.items(), key=lambda x: (x[0][1], str(x[0][2]))
-        ):
-            result.append(u'Лист "%s" (%s), строка %s:' % pos)
-            result.extend((u'  %s' % line) for line in sorted(lines))
-            result.append(u'')
+        for pos, lines in sorted(log.items(), key=lambda x: (x[0][1], str(x[0][2]))):
+            result.append(f'Лист "{pos[0]}" ({pos[1]}), строка {pos[2]}:')
+            result.extend(f'  {line}' for line in sorted(lines))
+            result.append('')
 
         return result
 
+
 if __name__ == '__main__':
 
     def cells_to_pair(cells):
@@ -1000,31 +911,24 @@ if __name__ == '__main__':
     config = {
         'test': {
             'date_and_int': {
-                'date': (u'date', DateCell()),
-                'int': (u'int', IntCell(default=-100)),
+                'date': ('date', DateCell()),
+                'int': ('int', IntCell(default=-100)),
             },
-            'mb_true': (
-                u'mb_true',
-                MaybeTrueCell(pattern='y', match_type=MATCH_IF_STARTS_WITH)
-            ),
-            'enum': (
-                u'enum',
-                EnumCell(choices=((1, 'aaa'), (2, 'bbb')), default=3)
-            ),
+            'mb_true': ('mb_true', MaybeTrueCell(pattern='y', match_type=MATCH_IF_STARTS_WITH)),
+            'enum': ('enum', EnumCell(choices=((1, 'aaa'), (2, 'bbb')), default=3)),
             'opt_strs': {
                 # SUBTREE_CAN_BE_EMPTY: False,
-                'date': (u'date', DateCell()),
-                'str': (u'str', StringCell()),
-                'mb_str': (u'mb_str', MaybeStringCell()),
-                'mb_int': (u'mb_int', MaybeIntCell()),
+                'date': ('date', DateCell()),
+                'str': ('str', StringCell()),
+                'mb_str': ('mb_str', MaybeStringCell()),
+                'mb_int': ('mb_int', MaybeIntCell()),
             },
             'pasport': (
-                RegexColumnMatcher(
-                    u'Номер паспорта', u'^(№|Номер) паспорта$'),
+                RegexColumnMatcher('Номер паспорта', '^(№|Номер) паспорта$'),
                 StringCell(),
             ),
             # Авто определение начала таблицы
-            START_ROW: DynamicStartRow([u'Date', u'Int']),
+            START_ROW: DynamicStartRow(['Date', 'Int']),
             # Не загружать последнюю строку
             END_ROW: -1,
             HEADER_PARSER: cells_to_pair,
@@ -1033,20 +937,17 @@ if __name__ == '__main__':
     with open('test_file.xls') as xls_file:
         ldr = XLSLoader(xls_file, config=config)
 
-        print("Loaded: %s" % ldr.load())
+        print(f'Loaded: {ldr.load()}')
 
         print('---- header ----')
-        print(u'\n'.join(
-            u'%s -> %r' % i
-            for i in ldr.headers['TEST']
-            if i
-        ))
+        print('\n'.join(f'{col} -> {val!r}' for col, val in ldr.headers['TEST'] if (col, val)))
 
         print('---- data ----')
         import pprint
+
         pprint.pprint(ldr.data)
 
         print('---- rows_log ----')
-        print(u'\n'.join(ldr.prepare_row_errors(ldr.rows_log)))
+        print('\n'.join(ldr.prepare_row_errors(ldr.rows_log)))
         print('---- log ----')
         pprint.pprint(ldr.log)
