@@ -1,25 +1,26 @@
-# coding: utf-8
-from __future__ import absolute_import
-
 import os
 import sys
 import uuid
 
-from simple_report.report import SpreadsheetReport
+from simple_report.report import (
+    SpreadsheetReport,
+)
 
-from educommon.report.reporter import get_path
-from educommon.report.reporter import get_url
+from educommon.report.reporter import (
+    get_path,
+    get_url,
+)
 
 
-class BaseFailureImportReport(object):
-    """Базовый класс отчета об импорте"""
+class BaseFailureImportReport:
+    """Базовый класс отчета об импорте."""
 
     template_name = None
     reports_dir = 'reports'
     default_extension = 'xlsx'
 
     def __init__(self, data):
-        """:param data - данные для отчета"""
+        """:param data - данные для отчета."""
 
         self.data = data
         # Текущая директория
@@ -32,9 +33,7 @@ class BaseFailureImportReport(object):
         self.out_file_path = get_path(self.base_name)
         # url адрес, по которому будет доступен отчет
         self.out_file_url = get_url(self.base_name)
-        self.report = SpreadsheetReport(os.path.join(
-            reports_dir, '%s.%s' % (self.template_name, self.default_extension)
-        ))
+        self.report = SpreadsheetReport(os.path.join(reports_dir, f'{self.template_name}.{self.default_extension}'))
 
         # Создадим директории, если их нет
         folder_path = get_path('')
@@ -42,5 +41,5 @@ class BaseFailureImportReport(object):
             os.makedirs(folder_path)
 
     def make(self):
-        """Сбор отчета"""
+        """Сбор отчета."""
         raise NotImplementedError
