@@ -47,7 +47,7 @@ class GridPanel(ext.ExtPanel):
         self.template = t
 
     @staticmethod
-    def _create_grid(pack, columns, grid_cls, group_by=None, **kwargs):
+    def _create_grid(pack, columns, grid_cls, group_by=None, force_fit=False, **kwargs):
         """Метод возвращает грид.
 
         :param grid_cls: класс грида
@@ -55,7 +55,7 @@ class GridPanel(ext.ExtPanel):
         :param str group_by: темплейт для группирования
         """
         grid = grid_cls(
-            region='north', force_fit=False, auto_scroll=True, auto_width=False, cls='word-wrap-grid', **kwargs
+            region='north', force_fit=force_fit, auto_scroll=True, auto_width=False, cls='word-wrap-grid', **kwargs
         )
         grid.flex = 1
         grid.sm = ext.ExtGridCellSelModel()
