@@ -1,52 +1,76 @@
-# coding: utf-8
-from __future__ import absolute_import
+from m3_ext.ui.containers import (
+    ExtContextMenu,
+    ExtContextMenuItem,
+)
+from m3_ext.ui.containers.container_complex import (
+    ExtContainerTable,
+)
+from m3_ext.ui.containers.containers import (
+    ExtContainer,
+    ExtToolBar,
+    ExtToolbarMenu,
+)
+from m3_ext.ui.containers.forms import (
+    ExtFieldSet,
+)
+from m3_ext.ui.containers.grids import (
+    ExtGrid,
+)
+from m3_ext.ui.containers.trees import (
+    ExtTree,
+)
+from m3_ext.ui.controls.buttons import (
+    ExtButton,
+)
+from m3_ext.ui.fields.simple import (
+    ExtCheckBox,
+    ExtStringField,
+    ExtTextArea,
+)
+from m3_ext.ui.misc.store import (
+    ExtDataStore,
+)
 
-from m3_ext.ui.containers import ExtContextMenu
-from m3_ext.ui.containers import ExtContextMenuItem
-from m3_ext.ui.containers.container_complex import ExtContainerTable
-from m3_ext.ui.containers.containers import ExtContainer
-from m3_ext.ui.containers.containers import ExtToolBar
-from m3_ext.ui.containers.containers import ExtToolbarMenu
-from m3_ext.ui.containers.forms import ExtFieldSet
-from m3_ext.ui.containers.grids import ExtGrid
-from m3_ext.ui.containers.trees import ExtTree
-from m3_ext.ui.controls.buttons import ExtButton
-from m3_ext.ui.fields.simple import ExtCheckBox
-from m3_ext.ui.fields.simple import ExtStringField
-from m3_ext.ui.fields.simple import ExtTextArea
-from m3_ext.ui.misc.store import ExtDataStore
-from objectpack.ui import ColumnsConstructor
-from objectpack.ui import ComboBoxWithStore
-from objectpack.ui import WindowTab
-from objectpack.ui import _create_control_for_field
-from objectpack.ui import make_combo_box
+from objectpack.ui import (
+    ColumnsConstructor,
+    ComboBoxWithStore,
+    WindowTab,
+    _create_control_for_field,
+    make_combo_box,
+)
 
-from educommon.objectpack.ui import BaseListWindow
-from educommon.objectpack.ui import TabbedEditWindow
-from educommon.utils.ui import local_template
-
-from .. import constants
-from .. import models
-from ..models import ReportTemplate
+from educommon.objectpack.ui import (
+    BaseListWindow,
+    TabbedEditWindow,
+)
+from educommon.report.constructor import (
+    constants,
+    models,
+)
+from educommon.report.constructor.models import (
+    ReportTemplate,
+)
+from educommon.utils.ui import (
+    local_template,
+)
 
 
 # -----------------------------------------------------------------------------
 # Окно просмотра списка шаблонов.
 class ListWindow(BaseListWindow):
-
-    u"""Окно просмотра списка шаблонов отчетов."""
+    """Окно просмотра списка шаблонов отчетов."""
 
     def _init_components(self):
         super(ListWindow, self)._init_components()
 
         self.grid.top_bar.button__build = ExtButton(
-            text=u'Собрать отчет',
+            text='Собрать отчет',
             icon_cls='database_table',
             handler='buildReport',
             disabled=True,
         )
         self.grid.context_menu_row.menuitem__build = ExtContextMenuItem(
-            text=u'Собрать отчет',
+            text='Собрать отчет',
             icon_cls='database_table',
             handler='buildReport',
         )
@@ -55,9 +79,7 @@ class ListWindow(BaseListWindow):
         super(ListWindow, self)._do_layout()
 
         self.grid.top_bar.items.insert(0, self.grid.top_bar.button__build)
-        self.grid.context_menu_row.items.append(
-            self.grid.context_menu_row.menuitem__build
-        )
+        self.grid.context_menu_row.items.append(self.grid.context_menu_row.menuitem__build)
 
     def set_params(self, params):
         super(ListWindow, self).set_params(params)
@@ -65,33 +87,31 @@ class ListWindow(BaseListWindow):
         self.template_globals = local_template('list-window.js')
 
         self.build_action_url = params['build_action_url']
+
+
 # -----------------------------------------------------------------------------
 # Вкладка "Столбцы" окна редактирования шаблона.
 
 
 class AvailableColumnsTree(ExtTree):
-
-    u"""Дерево доступных для использования в отчете столбцов."""
+    """Дерево доступных для использования в отчете столбцов."""
 
     class ToolBar(ExtToolBar):
-
         def __init__(self, *args, **kwargs):
             super(AvailableColumnsTree.ToolBar, self).__init__(*args, **kwargs)
 
             self.button__add = ExtButton(
-                text=u'Добавить в шаблон',
+                text='Добавить в шаблон',
                 icon_cls='add_item',
                 handler='addColumnToReport',
                 disabled=True,
             )
 
-            self.items[:] = (
-                self.button__add,
-            )
+            self.items[:] = (self.button__add,)
 
     def __init__(self, *args, **kwargs):
         kwargs.update(
-            title=u'Доступные наименования столбцов',
+            title='Доступные наименования столбцов',
             header=True,
             read_only=True,
         )
@@ -99,13 +119,15 @@ class AvailableColumnsTree(ExtTree):
 
         self.style = {'border-width': '1px'}
 
-        ColumnsConstructor.from_config((
-            dict(
-                data_index='title',
-                header=u'Наименование',
-                sortable=False,
-            ),
-        )).configure_grid(self)
+        ColumnsConstructor.from_config(
+            (
+                dict(
+                    data_index='title',
+                    header='Наименование',
+                    sortable=False,
+                ),
+            )
+        ).configure_grid(self)
 
         self.top_bar = self.ToolBar()
 
@@ -114,23 +136,21 @@ class AvailableColumnsTree(ExtTree):
 
 
 class ReportColumnsTree(ExtTree):
-
-    u"""Дерево используемых в шаблоне отчета столбцов."""
+    """Дерево используемых в шаблоне отчета столбцов."""
 
     class ToolBar(ExtToolBar):
-
         def __init__(self, *args, **kwargs):
             super(ReportColumnsTree.ToolBar, self).__init__(*args, **kwargs)
 
             self.button__remove = ExtButton(
-                text=u'Убрать столбец',
+                text='Убрать столбец',
                 icon_cls='delete_item',
                 handler='removeColumnFromReport',
                 disabled=True,
             )
 
             self.button__switch_visibility = ExtButton(
-                text=u'Скрывать',
+                text='Скрывать',
                 icon_cls='report-constructor-switch-visible',
                 handler='switchColumnVisibility',
                 hidden=True,
@@ -138,19 +158,13 @@ class ReportColumnsTree(ExtTree):
 
             # Промежуточный итог
             self.button__by_value_count = ExtContextMenuItem(
-                text=u'Количество',
-                icon_cls='icon-report-add',
-                handler='setByValueCountAggregator'
+                text='Количество', icon_cls='icon-report-add', handler='setByValueCountAggregator'
             )
             self.button__by_value_sum = ExtContextMenuItem(
-                text=u'Сумма',
-                icon_cls='icon-report-add',
-                handler='setByValueSumAggregator'
+                text='Сумма', icon_cls='icon-report-add', handler='setByValueSumAggregator'
             )
             self.button__by_value_none = ExtContextMenuItem(
-                text=u'Очистить',
-                icon_cls='icon-report-delete',
-                handler='setByValueNoneAggregator'
+                text='Очистить', icon_cls='icon-report-delete', handler='setByValueNoneAggregator'
             )
             context_menu__by_value = ExtContextMenu()
             context_menu__by_value.items.extend(
@@ -161,32 +175,24 @@ class ReportColumnsTree(ExtTree):
                 )
             )
             self.menu__by_value = ExtToolbarMenu(
-                icon_cls="icon-report",
+                icon_cls='icon-report',
                 menu=context_menu__by_value,
-                text=u'Промежуточный итог',
+                text='Промежуточный итог',
                 hidden=True,
             )
 
             # Итог
             self.button__total_count = ExtContextMenuItem(
-                text=u'Количество',
-                icon_cls='icon-calculator-add',
-                handler='setTotalCountAggregator'
+                text='Количество', icon_cls='icon-calculator-add', handler='setTotalCountAggregator'
             )
             self.button__total_uniq_count = ExtContextMenuItem(
-                text=u'Количество уникальных',
-                icon_cls='icon-calculator-add',
-                handler='setTotalCountUniqueAggregator'
+                text='Количество уникальных', icon_cls='icon-calculator-add', handler='setTotalCountUniqueAggregator'
             )
             self.button__total_sum = ExtContextMenuItem(
-                text=u'Сумма',
-                icon_cls='icon-calculator-add',
-                handler='setTotalSumAggregator'
+                text='Сумма', icon_cls='icon-calculator-add', handler='setTotalSumAggregator'
             )
             self.button__total_none = ExtContextMenuItem(
-                text=u'Очистить',
-                icon_cls='icon-calculator-delete',
-                handler='setTotalNoneAggregator'
+                text='Очистить', icon_cls='icon-calculator-delete', handler='setTotalNoneAggregator'
             )
             context_menu__total = ExtContextMenu()
             context_menu__total.items.extend(
@@ -198,9 +204,9 @@ class ReportColumnsTree(ExtTree):
                 )
             )
             self.menu__total = ExtToolbarMenu(
-                icon_cls="icon-calculator",
+                icon_cls='icon-calculator',
                 menu=context_menu__total,
-                text=u'Итог',
+                text='Итог',
                 hidden=True,
             )
 
@@ -213,7 +219,7 @@ class ReportColumnsTree(ExtTree):
 
     def __init__(self, *args, **kwargs):
         kwargs.update(
-            title=u'Столбцы в отчете',
+            title='Столбцы в отчете',
             header=True,
         )
         super(ReportColumnsTree, self).__init__(*args, **kwargs)
@@ -222,46 +228,42 @@ class ReportColumnsTree(ExtTree):
 
         self.style = {'border-width': '1px'}
 
-        ColumnsConstructor.from_config((
-            dict(
-                data_index='title',
-                header=u'Наименование',
-                sortable=False,
-            ),
-            dict(
-                data_index='visible',
-                hidden=True
-            ),
-            dict(
-                data_index='visible_title',
-                header=u'Отображать',
-                sortable=False,
-                width=20,
-                fixed=True,
-            ),
-            dict(
-                data_index='by_value',
-                hidden=True
-            ),
-            dict(
-                data_index='by_value_title',
-                header=u'Промежуточный итог',
-                sortable=False,
-                width=20,
-                fixed=True,
-            ),
-            dict(
-                data_index='total',
-                hidden=True,
-            ),
-            dict(
-                data_index='total_title',
-                header=u'Итог',
-                sortable=False,
-                width=20,
-                fixed=True,
-            ),
-        )).configure_grid(self)
+        ColumnsConstructor.from_config(
+            (
+                dict(
+                    data_index='title',
+                    header='Наименование',
+                    sortable=False,
+                ),
+                dict(data_index='visible', hidden=True),
+                dict(
+                    data_index='visible_title',
+                    header='Отображать',
+                    sortable=False,
+                    width=20,
+                    fixed=True,
+                ),
+                dict(data_index='by_value', hidden=True),
+                dict(
+                    data_index='by_value_title',
+                    header='Промежуточный итог',
+                    sortable=False,
+                    width=20,
+                    fixed=True,
+                ),
+                dict(
+                    data_index='total',
+                    hidden=True,
+                ),
+                dict(
+                    data_index='total_title',
+                    header='Итог',
+                    sortable=False,
+                    width=20,
+                    fixed=True,
+                ),
+            )
+        ).configure_grid(self)
 
         self.top_bar = self.ToolBar()
 
@@ -270,10 +272,9 @@ class ReportColumnsTree(ExtTree):
 
 
 class ColumnsTab(WindowTab):
+    """Вкладка "Колонки" окна редактирования шаблона отчета."""
 
-    u"""Вкладка "Колонки" окна редактирования шаблона отчета."""
-
-    title = u'Столбцы'
+    title = 'Столбцы'
 
     def init_components(self, win):
         super(ColumnsTab, self).init_components(win)
@@ -307,13 +308,14 @@ class ColumnsTab(WindowTab):
         self.grid__report_columns.set_params(params)
         self.grid__report_columns.drag_drop = True
         self.grid__report_columns.handler_beforedrop = 'onBeforeDrop'
+
+
 # -----------------------------------------------------------------------------
 # Вкладка "Фильтры" окна редактирования шаблона.
 
 
 class OperatorPanel(ExtFieldSet):
-
-    u"""Панель для поля "Оператор" на вкладке "Фильтры"."""
+    """Панель для поля "Оператор" на вкладке "Фильтры"."""
 
     def __init__(self, *args, **kwargs):
         super(OperatorPanel, self).__init__(*args, **kwargs)
@@ -327,12 +329,12 @@ class OperatorPanel(ExtFieldSet):
         self.field__operator = ComboBoxWithStore(
             name='operator',
             display_field='title',
-            label=u'Условие',
+            label='Условие',
             width=70,
         )
         self.field__operator.data = (
-            ('AND', u'И'),
-            ('OR', u'ИЛИ'),
+            ('AND', 'И'),
+            ('OR', 'ИЛИ'),
         )
 
         # Решили временно ограничить возможность выбора оператора, но
@@ -340,59 +342,54 @@ class OperatorPanel(ExtFieldSet):
         self.hidden = True
         self.field__operator.value = 'AND'
 
-        self.items[:] = (
-            self.field__operator,
-        )
+        self.items[:] = (self.field__operator,)
 
 
 class FilterParamsPanel(ExtContainerTable):
-
-    u"""Панель ввода параметров фильтра."""
+    """Панель ввода параметров фильтра."""
 
     def __init__(self, *args, **kwargs):
         super(FilterParamsPanel, self).__init__(columns=3, rows=4)
 
-        self.title = u'Параметры фильтра'
+        self.title = 'Параметры фильтра'
         self.style['padding-top'] = '5px'
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
         self.field__column = ComboBoxWithStore(
             name='column',
             value_field='name',
             display_field='title',
-            label=u'Столбец',
+            label='Столбец',
         )
 
         self.field__operator = ComboBoxWithStore(
             name='operator',
             display_field='title',
-            label=u'Условие',
+            label='Условие',
             data=(),  # ReportFilter.OPERATOR_CHOICES,
         )
-        self.field__operator.store.id_property = (
-            self.field__operator.value_field
-        )
+        self.field__operator.store.id_property = self.field__operator.value_field
 
         self.field__exclude = ExtCheckBox(
             name='exclude',
-            label=u'Обратное условие',
+            label='Обратное условие',
             disabled=True,
         )
 
         self.field__case_sensitive = ExtCheckBox(
             name='case_sensitive',
-            label=u'Учет регистра',
+            label='Учет регистра',
             disabled=True,
         )
 
         self.field__value = ExtStringField(
             name='values',
-            label=u'Значение',
+            label='Значение',
             disabled=True,
         )
 
         self.field__comment = ExtTextArea(
             name='comment',
-            label=u'Описание',
+            label='Описание',
             height=35,
             disabled=True,
         )
@@ -418,19 +415,18 @@ class FilterParamsPanel(ExtContainerTable):
 
 
 class FiltersGridTopBar(ExtToolBar):
-
-    u"""Верхняя панель грида с параметрами фильтрации."""
+    """Верхняя панель грида с параметрами фильтрации."""
 
     def __init__(self, *args, **kwargs):
         super(FiltersGridTopBar, self).__init__(*args, **kwargs)
 
         self.button__add = ExtButton(
-            text=u'Добавить',
+            text='Добавить',
             icon_cls='add_item',
             handler='addFilter',
         )
         self.button__delete = ExtButton(
-            text=u'Удалить',
+            text='Удалить',
             icon_cls='delete_item',
             handler='deleteFilter',
             disabled=True,
@@ -443,8 +439,7 @@ class FiltersGridTopBar(ExtToolBar):
 
 
 class FiltersGrid(ExtGrid):
-
-    u"""Грид с параметрами фильтрации данных в отчете."""
+    """Грид с параметрами фильтрации данных в отчете."""
 
     def __init__(self, *args, **kwargs):
         super(FiltersGrid, self).__init__(*args, **kwargs)
@@ -466,7 +461,7 @@ class FiltersGrid(ExtGrid):
         )
         self.add_column(
             data_index='column_title',
-            header=u'Столбец',
+            header='Столбец',
         )
         self.add_column(
             data_index='operator',
@@ -474,38 +469,37 @@ class FiltersGrid(ExtGrid):
         )
         self.add_column(
             data_index='operator_title',
-            header=u'Условие',
+            header='Условие',
             width=110,
             fixed=True,
         )
         self.add_check_column(
             data_index='exclude',
-            header=u'Обратное условие',
+            header='Обратное условие',
             width=90,
             fixed=True,
         )
         self.add_check_column(
             data_index='case_sensitive',
-            header=u'Учет регистра',
+            header='Учет регистра',
             width=85,
             fixed=True,
         )
         self.add_column(
             data_index='values',
-            header=u'Значение',
+            header='Значение',
         )
         self.add_column(
             data_index='comment',
-            header=u'Описание',
+            header='Описание',
         )
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 
 class FiltersTab(WindowTab):
+    """Вкладка "Фильтры" окна редактирования шаблона отчета."""
 
-    u"""Вкладка "Фильтры" окна редактирования шаблона отчета."""
-
-    title = u'Фильтры'
+    title = 'Фильтры'
 
     def init_components(self, win):
         super(FiltersTab, self).init_components(win)
@@ -533,24 +527,25 @@ class FiltersTab(WindowTab):
         self.panel__filter_params.flex = 0
         self.panel__filter_params.height = 120
         self.grid__filters.flex = 1
+
+
 # -----------------------------------------------------------------------------
 # Вкладка "Сортировка" окна редактирования шаблона.
 
 
 class SortingGridTopBar(ExtToolBar):
-
-    u"""Верхняя панель грида с параметрами сортировки."""
+    """Верхняя панель грида с параметрами сортировки."""
 
     def __init__(self, *args, **kwargs):
         super(SortingGridTopBar, self).__init__(*args, **kwargs)
 
         self.button__add = ExtButton(
-            text=u'Добавить',
+            text='Добавить',
             icon_cls='add_item',
             handler='addSort',
         )
         self.button__delete = ExtButton(
-            text=u'Удалить',
+            text='Удалить',
             icon_cls='delete_item',
             handler='deleteSort',
             disabled=True,
@@ -576,8 +571,7 @@ class SortingGridTopBar(ExtToolBar):
 
 
 class SortingGrid(ExtGrid):
-
-    u"""Грид для отображения параметров сортировки."""
+    """Грид для отображения параметров сортировки."""
 
     def __init__(self, *args, **kwargs):
         super(SortingGrid, self).__init__(*args, **kwargs)
@@ -599,7 +593,7 @@ class SortingGrid(ExtGrid):
         )
         self.add_column(
             data_index='column_title',
-            header=u'Столбец',
+            header='Столбец',
             width=1,
         )
         self.add_column(
@@ -608,20 +602,19 @@ class SortingGrid(ExtGrid):
         )
         self.add_column(
             data_index='direction_title',
-            header=u'Направление сортировки',
+            header='Направление сортировки',
             width=150,
             fixed=True,
         )
 
 
 class SortingParamsPanel(ExtFieldSet):
-
-    u"""Панель ввода параметров сортировки."""
+    """Панель ввода параметров сортировки."""
 
     def __init__(self, *args, **kwargs):
         super(SortingParamsPanel, self).__init__(*args, **kwargs)
 
-        self.title = u'Параметры сортировки'
+        self.title = 'Параметры сортировки'
         self.label_width = 150
         self.style['padding'] = '5px'
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -630,20 +623,18 @@ class SortingParamsPanel(ExtFieldSet):
             name='column',
             value_field='name',
             display_field='title',
-            label=u'Столбец',
+            label='Столбец',
             anchor='100%',
         )
 
         self.field__direction = ComboBoxWithStore(
             name='direction',
             display_field='title',
-            label=u'Направление сортировки',
+            label='Направление сортировки',
             data=constants.DIRECTION_CHOICES,
             anchor='100%',
         )
-        self.field__direction.store.id_property = (
-            self.field__direction.value_field
-        )
+        self.field__direction.store.id_property = self.field__direction.value_field
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         self.items[:] = (
@@ -653,10 +644,9 @@ class SortingParamsPanel(ExtFieldSet):
 
 
 class SortingTab(WindowTab):
+    """Вкладка "Сортировка" окна редактирования шаблона отчета."""
 
-    u"""Вкладка "Сортировка" окна редактирования шаблона отчета."""
-
-    title = u'Сортировка'
+    title = 'Сортировка'
 
     def init_components(self, win):
         super(SortingTab, self).init_components(win)
@@ -681,12 +671,13 @@ class SortingTab(WindowTab):
         self.grid__sorting.flex = 1
         self.panel__sorting_params.flex = 0
         self.panel__sorting_params.height = 80
+
+
 # -----------------------------------------------------------------------------
 
 
 class EditWindow(TabbedEditWindow):
-
-    u"""Окно добавления/редактирования шаблона отчета."""
+    """Окно добавления/редактирования шаблона отчета."""
 
     tabs = (
         ColumnsTab,
@@ -707,7 +698,7 @@ class EditWindow(TabbedEditWindow):
         )
         self.field__data_source_name = make_combo_box(
             name='data_source_name',
-            label=u'Источник данных',
+            label='Источник данных',
             display_field='title',
             value_field='name',
             allow_blank=False,
@@ -718,8 +709,7 @@ class EditWindow(TabbedEditWindow):
             anchor='100%',
         )
         self.field__include_available_units = _create_control_for_field(
-            getattr(ReportTemplate, '_meta').get_field(
-                'include_available_units'),
+            getattr(ReportTemplate, '_meta').get_field('include_available_units'),
             anchor='100%',
         )
 
@@ -752,10 +742,9 @@ class EditWindow(TabbedEditWindow):
         self.height, self.width = 600, 1000
         self.template_globals = local_template('edit-window.js')
 
-        self.field__data_source_name.store = ExtDataStore(tuple(
-            (name, data_source_param.title)
-            for name, data_source_param in params['data_sources_params']
-        ))
+        self.field__data_source_name.store = ExtDataStore(
+            tuple((name, data_source_param.title) for name, data_source_param in params['data_sources_params'])
+        )
         self.field__data_source_name.store.id_property = 'name'
         self.field__data_source_name.store.reader.set_fields('title')
 
