@@ -9,10 +9,6 @@ from mptt.models import (
     TreeForeignKey,
 )
 
-from objectpack.exceptions import (
-    ValidationError,
-)
-
 from educommon.django.db.mixins.validation import (
     post_clean,
 )
@@ -34,6 +30,9 @@ from educommon.report.constructor.validators import (
 from educommon.utils.misc import (
     cached_property,
 )
+from objectpack.exceptions import (
+    ValidationError,
+)
 
 
 class ReportTemplate(CascadeDeleteMixin, BaseModel):
@@ -331,9 +330,7 @@ class ReportFilter(BaseModel):
         'Исключать записи, удовлетворяющие условию',
         default=False,
     )
-    case_sensitive = models.NullBooleanField(
-        'Учет регистра',
-    )
+    case_sensitive = models.BooleanField('Учет регистра', null=True)
     values = ArrayField(
         models.TextField(
             'Значение',
