@@ -1,19 +1,18 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-from datetime import datetime
+from datetime import (
+    datetime,
+)
 
 
 def get_string_value(text):
-    u"""Возвращает строковое значение."""
-    text = text.replace(u'\n', u' ')
-    while text.find(u'  ') != -1:
-        text = text.replace(u'  ', u' ')
+    """Возвращает строковое значение."""
+    text = text.replace('\n', ' ')
+    while text.find('  ') != -1:
+        text = text.replace('  ', ' ')
     return text
 
 
 def get_int_value(text):
-    u"""Возвращает числовое значение."""
+    """Возвращает числовое значение."""
     text = get_string_value(text)
     result = None
     if text:
@@ -25,7 +24,7 @@ def get_int_value(text):
 
 
 def get_date_value(text, xml_format=False):
-    u"""Возвращает значение даты.
+    """Возвращает значение даты.
 
     :param text basestring: Строковое значение поля.
     :param boolean xml_format: Флаг формата даты, принятой для типа данных
@@ -37,6 +36,6 @@ def get_date_value(text, xml_format=False):
 
 
 def get_bool_value(text):
-    u"""Возвращает булевое значение."""
+    """Возвращает булевое значение."""
     text = get_string_value(text)
     return True if text.lower() == 'true' else False
